==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/core/camel-core/src/test/java/org/apache/camel/processor/ClaimCheckEipDynamicKeyGetSetTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.model.ClaimCheckOperation;
import org.junit.jupiter.api.Test;

public class ClaimCheckEipDynamicKeyGetSetTest extends ContextTestSupport {

    @Test
    public void testGetSet() throws Exception {
        getMockEndpoint("mock:a").expectedBodiesReceived("Hello World", "Bonjour World");
        getMockEndpoint("mock:b").expectedBodiesReceived("Bye World", "Bye World");
        getMockEndpoint("mock:c").expectedBodiesReceived("Hello World", "Bonjour World");
        getMockEndpoint("mock:d").expectedBodiesReceived("Hi World", "Hi World");
        getMockEndpoint("mock:e").expectedBodiesReceived("Hello World", "Bonjour World");

        template.sendBodyAndHeader("direct:start", "Hello World", "myHeader", "foo");
        template.sendBodyAndHeader("direct:start", "Bonjour World", "myHeader", "bar");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").to("mock:a").claimCheck(ClaimCheckOperation.Set, "${header.myKey}").transform().constant("Bye World").to("mock:b")
                    .claimCheck(ClaimCheckOperation.Get, "${header.myKey}").to("mock:c").transform().constant("Hi World").to("mock:d")
                    .claimCheck(ClaimCheckOperation.Get, "${header.myKey}").to("mock:e");
            }
        };
    }
}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/core/camel-core/src/test/java/org/apache/camel/processor/ClaimCheckEipDynamicKeyGetSetTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.processor;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.model.ClaimCheckOperation;
import org.junit.jupiter.api.Test;

public class ClaimCheckEipDynamicKeyGetSetTest extends ContextTestSupport {

    @Test
    public void testGetSet() throws Exception {
        getMockEndpoint("mock:a").expectedBodiesReceived("Hello World", "Bonjour World");
        getMockEndpoint("mock:b").expectedBodiesReceived("Bye World", "Bye World");
        getMockEndpoint("mock:c").expectedBodiesReceived("Hello World", "Bonjour World");
        getMockEndpoint("mock:d").expectedBodiesReceived("Hi World", "Hi World");
        getMockEndpoint("mock:e").expectedBodiesReceived("Hello World", "Bonjour World");

        template.sendBodyAndHeader("direct:start", "Hello World", "myHeader", "foo");
        template.sendBodyAndHeader("direct:start", "Bonjour World", "myHeader", "bar");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("direct:start").to("mock:a").claimCheck(ClaimCheckOperation.Set, "${header.myKey}").transform()
                        .constant("Bye World").to("mock:b")
                        .claimCheck(ClaimCheckOperation.Get, "${header.myKey}").to("mock:c").transform().constant("Hi World")
                        .to("mock:d")
                        .claimCheck(ClaimCheckOperation.Get, "${header.myKey}").to("mock:e");
            }
        };
    }
}
